@@ -2,11 +2,10 @@
 
 """Idiomatic conversion between URIs and compact URIs (CURIEs)."""
 
-from .api import Converter, chain
+from .api import Converter, DuplicatePrefixes, DuplicateURIPrefixes, Record, chain
 from .sources import (
     get_bioregistry_converter,
     get_go_converter,
-    get_go_obo_converter,
     get_monarch_converter,
     get_obo_converter,
     get_prefixcommons_converter,
@@ -15,6 +14,9 @@ from .version import get_version
 
 __all__ = [
     "Converter",
+    "Record",
+    "DuplicateURIPrefixes",
+    "DuplicatePrefixes",
     "chain",
     "get_version",
     "get_obo_converter",
@@ -22,5 +24,4 @@ __all__ = [
     "get_monarch_converter",
     "get_go_converter",
     "get_bioregistry_converter",
-    "get_go_obo_converter",
 ]
